@@ -1,16 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
+from urllib.request import urlopen
 
-try:
-    from urllib.request import urlopen
-except ImportError:
-    from urllib import urlopen
-
-import io
 import json
 import os
-import re
 import subprocess
 import sys
+import getpass
 
 
 def get_json(url):
@@ -29,37 +24,41 @@ def download_github_artifacts():
     for asset in release['assets']:
         download_file(asset['browser_download_url'], 'dist/{name}'.format(**asset))
 
+
 def get_version():
-    return subprocess.check_output([sys.executable, 'setup.py', '--version']).strip()
+    return subprocess.check_output(
+        [sys.executable, 'setup.py', '--version'],
+        encoding='utf8'
+    ).strip()
+
 
 def artifact_matcher(version):
-    return re.compile('^xattr-{}.*\\.(exe|whl)$'.format(re.escape(version)))
+    prefix = 'xattr-{}'.format(version)
+    def matches(fn):
+        return (
+            fn.startswith(prefix) and
+            os.path.splitext(fn)[1] in ('.exe', '.whl') and
+            not fn.endswith('-none-any.whl')
+        ) or fn == '{}.tar.gz'.format(prefix)
+    return matches
 
-def sign_artifacts(version):
-    artifacts = set(os.listdir('dist'))
-    pattern = artifact_matcher(version)
-    for fn in artifacts:
-        if pattern.search(fn) and '{}.asc'.format(fn) not in artifacts:
-            sign_artifact(os.path.join('dist', fn))
-
-def sign_artifact(path):
-    print(' '.join(['gpg', '--detach-sign', '-a', path]))
-    subprocess.check_call(['gpg', '--detach-sign', '-a', path])
 
 def upload_artifacts(version):
     artifacts = set(os.listdir('dist'))
-    pattern = artifact_matcher(version)
+    matches = artifact_matcher(version)
     args = ['twine', 'upload']
-    for fn in artifacts:
-        if pattern.search(fn):
-            filename = os.path.join('dist', fn)
-            args.extend([filename, filename + '.asc'])
+    for fn in filter(matches, artifacts):
+        args.append(os.path.join('dist', fn))
     subprocess.check_call(args)
 
+
 def main():
+    try:
+        os.makedirs('dist')
+    except OSError:
+        pass
     download_github_artifacts()
     version = get_version()
-    sign_artifacts(version)
     upload_artifacts(version)
 
 
